#
# spec file for package zim
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Matthias Propst.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1

Name:           zim
Version:        0.75.2
Release:        1.1
Summary:        A Desktop Wiki
License:        GPL-2.0-or-later
Group:          Productivity/Office/Organizers
URL:            https://zim-wiki.org
Source:         https://zim-wiki.org/downloads/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
# For directory ownership
BuildRequires:  %{python_module gobject >= 3.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3 >= 3.6.0
BuildRequires:  typelib-1_0-Gtk-3_0
BuildRequires:  update-desktop-files
Requires:       python3-gobject-Gdk
Requires:       python3-pyxdg
Requires:       typelib-1_0-Gtk-3_0
Requires:       xdg-utils
# for the version control plugin
Suggests:       bzr
Suggests:       git-core
Suggests:       mercurial
BuildArch:      noarch

%description
Zim is a graphical text editor used to maintain a collection of wiki
pages. Each page can contain links to other pages, simple formatting and
images. Pages are stored in a folder structure, like in an outliner, and
can have attachments. Creating a new page is as easy as linking to a
nonexistent page. All data is stored in plain text files with wiki
formatting. Various plugins provide additional functionality, like a
task list manager, an equation editor, a tray icon, and support for
version control.

%lang_package

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%suse_update_desktop_file %{name}
# remove ubuntu-specific icons
rm -r %{buildroot}%{_datadir}/icons/{ubuntu-mono-dark,ubuntu-mono-light}
%find_lang %{name}

%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%license LICENSE
%doc CHANGELOG.md PLUGIN_WRITING.md CONTRIBUTING.md
%{python_sitelib}/%{name}/
%{python_sitelib}/%{name}-%{version}-py*.egg-info
%{_bindir}/%{name}
%{_datadir}/%{name}/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.zim_wiki.Zim.appdata.xml
%{_datadir}/applications/zim.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/icons/hicolor/*/apps/zim.*
%{_datadir}/icons/hicolor/*/mimetypes/application-x-zim-notebook.*
%{_mandir}/man1/zim.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Jul 10 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 0.75.2:
  * Add pagename completion by words in "Jump to"
  * Let tasklist window remember selection state
  * Let tasklist window use a search bar
  * Add count in tasklist window
  * Fix auto-collapse in page index for child nodes
  * Fix import of gtkspellcheck
  * Make spellcheck more robust for page reload
  * Fix bug in insert screenshot
  * Add scrollbar to custom tool window
  * Fix config dirs for portable install
  * Use environment variable for XDG_TEMPLATES_DIR
  * Fix links to anchors on export
  * Fix bug in copy-paste of interwiki links
  * Updated diagrameditor and sequencediagrameditor plugins to generate SVG
  * Add keybinding for cutting the current line(s)
  * Fix fullscreen headerbar visibility
* Wed Jan 18 2023 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Added missing dependency on typelib-1_0-Gtk-3_0 (bsc#1188958)
* Wed Nov  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.75.1:
  * Fix bug with relative path notebook icon
  * Fix bug with icons in notebookdialog
  * Fix bug with loading sub-notebooks via "notebook.zim"
  * Fix bug with "--list" commandline
  * Fix issue opening unicode attachements on win32
  * Fix saving preferences for edit bar
  * Fix link visibility in TableEditor
  * Use flatpak locale directory in flatpak
  * Upgrade Python version requirement to >= 3.6
  * Complete porting all modules to `zim.newfs` and deprecate `zim.fs`
  * Refactor APIs to deal with tokens instead of `etree` interface
  * Add framework for imagegenerators with inline data
  * Refactored ther user interface of the tasklist plugin
  * Make tasklist window persistent
  * Let tasklist window also show closed tasks
  * Let tasks inherit all modifiers from list heading
  * Let "Go to Today" use anchor id for current day
  * Update LinkMap with new options
  * Refactor preference for custom window decoration & toolbar plugin
  * Enables distinct shortcuts for en and em dashes in symbol list
  * Add unicode 8757 ("because") in symbol list
  * Move Selected Text: add preference for short links & save bounds
  * Extend ToC pane context menu
  * Score editor: add check for convert-ly
  * Source View plugin: Don't show hidden languages
  * Export code blocks in markdown as fenced blocks
  * Fix loading GIF images
  * Fix to let the "insert link" dialog allow anchors
  * Allow sidepane focus key to be configured
  * Added action to collapse and expand in PageIndex
  * Add action for "move text" to allow keybinding
  * Support closing an open 'find bar' by pressing ESC in the page view widget
  * Allow cancelling ImageGeneratorDialog using Escape key
  * Version control: fix fossil
  * Fix KDE drag-n-drop bug
  * Fix export with formatting in heading
  * Minimal support for "Terminal" option in desktop files
  * Add preference for not prompting on new folder
* Sun Dec 12 2021 Cor Blom <cornelis@solcon.nl>
- Update to 0.74.3:
  * Fix issue with brioken links on move page
  * Fix bug in copy-paste
  * Fix bug on move page for existing textbuffer
  * Fix bug with saving of notebook editable state
  * Fix for error while loading plugins
  * Fix issue with stray unicode character
  * Fix issue to allow relative document root
  * Fix hack for rendering sourceview blocks
  * Add mnemonic keys to open sidepane tabs
  * Add links and screenshot to macOS app & update README
    information
  * Improve inline rendering of equations & make image DPI
    confingurable
  * Add box drawing characters to symbols list
  * Scroll on moving lines with linesorter plugin
  * Move floating table of contents to overlay layer
* Mon Nov  8 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Replace python3-gobject with python3-gobject-Gdk Requires. This
  should fix boo#1188958.
* Sat Oct 16 2021 Cor Blom <cornelis@solcon.nl>
- Update to 0.74.2:
  * Let Toolbar plugin also remove window decoration
  * Fix execution of custom tools from Toolbar
  * Add plugin "view" items to Toolbar plugin
  * Make drag&drop optional in the pageindex
  * Add option to toggle tooltips for index panes
  * Fix Zeitgeist plugin to work with Gtk3 branch
  * Improve dialog feedback for invalid input
  * Fix error on cancel insert dialog
  * Let exceptions not block search
  * Make page parser robust for empty files
- Update to 0.74.1:
  * Add preference to hide edit bar
  * Add separate parameter for wrapped lines linespacing
  * Fix behavior of copying images on copy-paste
  * Fix export of anchors to make valid HTML tags
  * Fix storing of uistate for window panes
  * Fix issues for "file:/path" file URIs
  * Fix bug in "copy link"
  * Make clipboard handling robust for non-local file URI
  * Fix issue with escaping in find input
  * Fix behavior of TrashDialog on error
  * Remove string literal formatting syntax
- Update to 0.74.0:
  * Support link "anchors" to allow linking within page
  * Add new-style headerbar as window decoration
  * Add auto-hiding headerbar in full screen mode
  * Add confirmation dialog when trashing pages
  * Replace toolbar by a plugin, introduce "Edit Bar" in pageview
  * Remove statusbar
  * Make single page window editable
  * Keep undostack for the last 10 pages
  * Copy equations on copy-paste
  * Copy image attachments on copy-paste
  * Update relative links on copy-paste formatted text
  * Fix copy-pasting links to another notebook
  * Add Bullet Journal "back arrow" checkbox
  * Add default browser to preferences
  * Add option to paste short relative link names
  * Add support for "INCLUDE file" in templates
  * Add `<Ctrl><Shift>C` for copying the current line
  * Show plugins that failed to load in the plugin list
  * Add auto-expand and -collapse options to tags plugin
  * Add option for horizontal scrollbar to pageindex & tags plugins
  * Add "open backlink in new window" in backlinks plugin
  * Add count and full path options for backlinks plugin
  * Add rename and delete menu entries in attachmentbrowser
  * Improve language selection for sourceview plugin
  * Add border width preference to sourceview plugin
  * Add dark mode preference to equation editor
  * Add Toolbar plugin, including "classic" mode
  * Add Command Palette plugin
  * Also match URL in wiki text for local network
  * Improve read performance for large text attachments
  * Fix issue with unicode mismatch in link and page names
  * Make indexer robust against false folder mtime
  * Make windows installer robust against overwriting data
  * Try to use GtkSourceView 4.x if 3.x not found
  * Fix numbered lists with letters in Markdown export
  * Use Pillow fallback to load WebP images
  * Make appending to page undo-able
  * Highlight "Toggle Editable" button when read-only
  * Add extensions on PageWindow by splitting NotebookView and PageView
  * Show link destination for keyboard navigation
  * Exclude formatting when copying headings
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.73.5:
  * Fix regression for “www.” links in pages
  * Fix bug with email address or url wrapped in higlight markup
  * Fix bug with handling newline in inline formatting
  * Fix bug when deleting a bullet-like sequence
  * Fix bug with relative links in single page export
  * Fix bug if notebook name is not set
  * Interpret pasted text as “wiki” format and add “Paste As Verbatim”
  * Update default application lookup to latest spec
  * Fix portable environment windows installer
  * Merge Weblate translations
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.73.4:
  * Fix issue with relative links on windows
  * Fix reload page after change in external editor
  * Fix regressions due to python3.9 change in ElementTree
  * Fix regression in nested format in link
  * Fix test failure in testing translations
  * Let versions control plugin initialize git repro to not quote non-ascii paths
  * Update markdown extension and mime-type
  * Merge translations
  * Fix missing export formats in windows installer
  * Add support for environ.ini at startup for portable install
  * Make trash function more robust for GLib.Error errors
  * Remove xdg import in windows for mimetyping
  * Fix regression with GdkPixbuf.PixbufRotation constants
  * Fix issues in parser under Python 3.9
  * Fix regression with pages with formatting in heading
  * Merge translations
* Tue Sep 29 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.73.2:
  + Add "show debug log" menu item
  + Add missing "triangle" icons for windows installer
  + Include helper to spawn external processes for windows installer
  + Fix dropdown namespace autocomplete in move-page dialog
  + Fix wiki parser for case of nested URL
  + Fix ParseTreeBuilder interface for python3.9
  + Add debug output for drag-and-drop workaround
  + Fix popup menu in attachment browser plugin
  + Fix warnings during export for "page.meta"
  + Fix on-preferences-changed for tableofcontents plugin
* Thu Jul  9 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.73.1:
  + Fix regression for opening single instance
  + Fix exception on toggle format
  + Fix failing tests due to change in sorting python3.8
  + Make robust for deprecation of cElementTree in python3.9
  + Improve tmpdir usage by using tempfile.mkdtemp()
  + Add ability to combine formatting styles in editor
  + Improve URL and link parsing to look for matching brackets
  + Reduce the number of - needed to auto-format a horizontal line
  + Allow typing bullet after e.g. checkbox to replace it
  + Add autoformat for sub- and super-script by typing ^.. and _{..}
  + On autoformat headings also strip trailing =
  + Fix issue with lost formatting when using spellchecker
  + Add support for "paragraph-background" property in style.conf
  + Improve keyboard behavior of find bar in editor
  + Swap the layout in the InsertDateDialog
  + Allow re-arranging side pane tabs by drag and drop
  + Add option to automatically collapse sections in the pageindex
  + Fix regression for inserting links on "Attach file" and moved this function to the Insert menu
  + Merge MovePageDialog and RenamePageDialog into a single dialog
  + Fix behavior when renaming non-existing "placeholder" pages
  + Add workaround for drag-and-drop issue #390
  + Whitelist image formats in latex export to avoid invalid image types
  + Add MacOS menubar plugin & fix for main menu mnemonics in MacOS
  + Give temporary directories unique names to improve robustness
  + Support TEXTDOMAINDIR evironment variable to set locale directory
  + Improve folder checks for automount feature
  + Improve window colors in distraction free mode
  + Add option to set the wrap-mode in sourceview
  + Add theme choice for the source view plugin
  + Add "private" switch to server command for commandline usage
  + Add authentication support to web server
  + Add template selection option to web server dialog
  + Add option for fontsize to table of contents plugin
  + Add option to show horizontal lines in table of contents
- Remove zim-CVE-2020-10870-tempdir.patch
* Tue Mar 24 2020 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Update to version 0.72.1:
  + Update translations & documentation
- CVE-2020-10870: Fixed a denial-of-service via predictable temporary directories (bsc#1167519).
  zim-CVE-2020-10870-tempdir.patch
* Thu Sep 19 2019 Luke Jones <luke@ljones.dev>
- Update to version 0.72:
  + Improve pathbar with "linked" visual design
  + Improve statusbar visual style
  + Change behavior for lists with mixed bullets
  + Add configuration of keybindings to preferences dialog
  + Support gnome-screenshot in the insert screenshot pluing
  + Save size of secondary page window
  + Add option for linenumbers option in insert code block dialog
  + Add option to display date column in tasklist side pane
  + Add warnings if locale does not support unicode
  + Make SVG thumbnail support configurable
  + Fix bug for insert equation and other objects
  + Fix use of escape sequence in table cells
  + Fix tasklist view for multiple dates in task
  + Fix "apply heading" to strip list formatting
  + Make ToC plugin update instead of refresh on save
  + Fix issue with not-unique headings in tableofcontents
  + Fix bugs in auto insert bullet at newline
- Update to version 0.71.1:
  + Fix robustness for OSError on process startup
  + Fix for popup menu on page index for Gtk < 3.22
  + Updated translations
- Update to version 0.71:
  + Fix "spill over" between translation files
  + Fix use of popup menus
  + Hack to work around textview glitches embedded objects
  + Make indexer recover from duplicate page names
  + Fix recovery of broken index file on startup
  + Restore New Sub Page for index context menu
  + Let customtools replace autoselected words and insert
  + Fallback encoding when calling external applications
  + Hide pathbar in distraction free mode
  + Merge fix for unicode completion in dialogs
  + Remember cursor position on reload
  + Fix inlinecalculator plugin
  + Update Gtk prerequisite version to 3.18
  + Updated Russian translation
- Update to version 0.70:
  * Ported zim to use Python3 & Gtk3
  * Refactored application framework, all windows run single process now with single plugin manager and preferences manager
  * Refactored plugin extension loading code and added functions to find extensions and actions
  * Removed the notebook "profile" properties
  * Plugins now can use notebook properties to store settings per notebook
  * The page index side pane and the pathbar are now plugins
  * Redesign journal plugin sidepane view and remove dialog
  * Renamed "calendar" plugin to "journal"
  * Removed OSX menubar plugin
  * Image generator plugins now are "inserted objects"
  * Workaround for missing clipboard.set_with_data()
  * Improved speed of test suite and refactored test constructs
  * Support flatpack-spawn to execute processes
  * Critical fix for updating links on move page and rename page
  * Critical fix for parsing headers when page has no title
  * Fix page index issue on delete page
* Sat Mar  2 2019 Karl Cheng <qantas94heavy@gmail.com>
- Fix missing python-xml runtime requirement.
* Mon Dec 17 2018 Karol Babioch <kbabioch@suse.de>
- Update to version 0.69:
  * Performance improvements for indexing large notebooks
  * Performance improvement for auto-completion of page names in dialogs
  * Updated translations from launchpad
* Fri Mar 23 2018 qantas94heavy@gmail.com
- Update to version 0.68:
  * Critical fixes:
    + For updating links on move page and rename page
    + For rename page and indexing on case-insensitive file systems
    (like windows)
  * Fix regressions:
    + In tasklist option to _not_ regard all checkboxes as tasks
    + In index navigation with previous page and next page
  * Other fixes:
    + Memory leak in spell checker plugin
    + Multi-line selections in linesorter plugin
    + Opening notebook list from tray icon
    + "-s" commandline argument for exporting
    + importing attachments in quicknote plugin commandline use
  * New features:
    + Pathbar now reveals more path elements in case of ambiguous
    pages
    + Add "font" property for use in "styles.conf"
    + Add "navigation.home" to template parser for export
    + Extend interface for "image generator" plugins
  * Miscellaneous changes:
    + Version control plugin updated to better handle git staging
    + Code cleaned up to be a bit PEP8 compliant and more future
    proof for python3 conversion
- Rename appdata XML to reflect changed component ID
  * Also relocate to /usr/share/mimeinfo instead of legacy
    /usr/share/appdata
* Sat Sep 23 2017 luc14n0@linuxmail.org
- Update to version 0.67:
  + Critical fixes:
  - For missing page headers & remembering custom headers.
  - By removing dependency on threading for index and socket
    handling.
    . Hidden option to also do autosave without thread to test
    further issues.
  - For handling unicode file names on windows.
  + More robustness:
  - For socket errors, fallback to --standalone automaticlly.
  - At startup when default notebook went missing, fallback
    to --list.
  - In preferences dialog when plugins give exceptions.
  - For invalid dates in tasklist parser.
  + Merge patch to add accelerators for bookmarks.
  + Fix regressions:
  - In close-page when autosave ongoing.
  - Drag-n-drop index pane.
  - For keybindings in index pane.
  - For attaching files.
  - For opening folders.
  - In opening inter-wiki links.
  - In custom tools.
  - In completion of page name in dialog entry.
  - In quicknote "--attachments" option.
  - For quicknote plugin due to process management.
  - In date format for recentchanges dialog.
  - In custom tool execution.
  + Fixes for unicode: In auto-linking and arithmetic plugin.
  + More fixes:
  - "insert image" also inserting a text link.
  - Search regex for chinese language to not match whitespace for
    start/end of word.
  - Table editor plugin when sorting rows.
  - Wrong usage of escapes in latex export for verbatim blocks.
  - The issue where config values go missing if not used.
  - Error for file shortcuts in various dialogs.
  - Indexing errors on move/rename page.
- Changes from version 0.66:
  + Multiple notebooks run as single process now to reduce
    multi-process complexity - more robust startup, reduce need for
    "--standalone".
  + SQLite indexer re-written to fix long standing bugs and design
    flaws with indexing.
  + Improved performance tag filtering in side pane.
  + Detect pages have changed on disk, even when page present in
    cache.
  + Bug fix for drag-n-drop of text within the editor.
  + New checkbox type available for "moved task" for journal
    workflow.
  + Context menu defined for checkboxes.
  + Horizontal lines "<HR>" added to wiki syntax.
  + Pathbar buttons can now also be used to insert page links by
    drag-n-drop.
  + Added to context mennu for pages: "search in section" and
    "search backlinks".
  + Keyboard navigation of plugin tab in preferences dialog.
  + Allow "mailto:" links contain arguments like "?subject=".
  + Tasklist plugin:
  - Now also available embedded in side pane.
  - New:
    . Syntax for including due and start dates.
    . Formatting priority column including
    deadlines.
    . "flat list" mode to only see lowest level tasks.
  - Removed support for "next" label.
  - Dialog now remembers sorting.
  + Versioncontrol plugin:
  - git: removed global "git add", instead
    stage individual files.
  - fossil: fix for fossil "addremove".
  + Attachment browser: bug fix for drag-n-drop.
  + Linesorter plugin: added keybindings to move / duplicate /
    delete lines.
  + Sourceview plugin:
  - Bug fixes:
    . To make export via commandline also use objects.
    . To follow editable state of parent window.
  + Bookmarks plugin updates.
  + Tableeditor plugin: bug fix for links.
  + Linkmap plugin: bug fix "unexpected char '-'".
  + Arithmic plugin: bug fix to allow negative numbers.
  + Dev:
  - Templates are now translatable, using "gettext()".
  - Index API completely changed, see tasklist for a plugin
    example.
  - New:
    . Module for file-system interaction, to be used in new
    code.
    . Parsing strategy based on tokenlist, used for tasklist
    parser.
  - Defined notebook API for concurrent operations in gtk main
    loop.
  - Simplified SignalEmitter code.
  + Packaging:
  - Removed support for maemo build - code went stale.
  - Make package build reproducible.
  + Updated translations.
- Drop /usr/bin/update-mime-database in %%post/%%postun: its use is
  obsolete and now is covered by file triggers.
- Add conditional %%desktop_database_*, %%icon_theme_cache_* and
  %%mime_database_* post/postun macros for versions older than
  tumbleweed: tumbleweed and factory now use file triggers.
- Add conditional use to shared-mime-info BuildRequires: only old
  suse versions need it.
- Drop obsoleted conditionals for versions older than 11.2: not
  needed/used.
* Wed Nov 11 2015 thehejik@suse.com
- Updated to version 0.65:
  + <Control> keybindings fail for older gtk versions, and in
    particular for the <Control><Space> keybinding.
  + The table editor tends to drop columns of content in the
    precences of empty cells.
  + Features from 0.64
  - Bookmark plugin.
  - Updated spell plugin to allow using gtkspellcheck as backend.
  - Updated attachmentbrowser plugin with new thumbnailing logic.
  - Speed up of sqlite indexing.
  - Updated support for OS X.
  - Bug fixes for the Fossil version control support.
  - Bug fixes for locale in strftime and strxfrm functions.
  - Bug fix to avoid overwriting the accelmap config file.
* Mon Jun 15 2015 dimstar@opensuse.org
- Update to version 0.63:
  + Table plugin.
  + Support for Fossil version control.
  + Many bug fixes.
* Wed Oct  1 2014 dimstar@opensuse.org
- Update to version 0.62 (boo#899449):
  + Fixed broken Source View plugin.
  + Fixed Tray Icon plugin for Ubuntu.
  + Fixed bug with Caps Lock on windows.
  + Fixed behavior of New Page dialog.
  + Fixed status parsing for Git backend.
  + Fixed bug with CamelCase parsing for Persian & Arabic script.
  + Fixed parsing of numbered list character to be robust for
    Chinese characters.
  + Fixed bug with www server dialog.
  + Fixed bug in Go Child Page action.
  + Fixed export using the S5 slideshow template - now splits by
    heading.
  + Fixed bug in indexing for python 2.6.
  + Fixed bug in Open Notebook dialog when selecting current
    notebook.
  + Changed lookup path for 3rd party plugin modules - now uses XDG
    path.
  + Merged patch to support more screenshot tools in the Insert
    Screenshot plugin.
  + Updated Sort Lines plugin to use natural sorting for unicode.
  + Added control for handling of line breaks in HTML export.
  + Changed rendering of checkboxes in HTML export.
  + Merged patch to set image size for GNU R plugin.
  + Added control to toggle full page name in Tag index view.
  + Added handling of SIGTERM signal.
* Fri Aug  8 2014 dimstar@opensuse.org
- Update to version 0.61:
  + Full refactoring of code for parsing and processing wiki syntax
    making parser easier to extend and document interface more
    scalable.
  + Full refactoring of code for plugin framework making plugins
    more flexible by defining decorators for specific application
    objects.
  + Full refactoring of code for exporting pages from zim
  - Now supports MHTML export format.
  - Supports exporting multiple pages to a single file.
  - Supports recursive export of a page and all it's sub-pages.
  - Templates now support many more instructions and expressions.
  + Full refactoring of the code for parsing commandline commands
    and initializing the application.
  + New config manager code to make parsing and handling of config
    files more robust.
  + Merged new plugin for editing sequence diagrams.
  + Improved the ToC plugin with floating widget.
  + Fixed unicode issue when calling external applications, and in
    particular for the hg and git commands.
  + Fixed support for unicode CamelCase word detection.
  + Fixed bug on windows with unicode user names in background
    process connection.
  + Changed "tags" plugin to show full page paths in the pre-tag
    view.
  + Added option for custom commands to replace the current
    selection.
  + Added keybindings for XF86Back and XF86Forward.
  + Many small fixes & patches.
  + Updated translations.
- Add python-xml BuildRequires: new dependency.
* Fri May  3 2013 dimstar@opensuse.org
- Update to version 0.60:
  + In this release the required python version is changed from
    2.5 to 2.6.
  + Added a Recent Changes dialog and a Recent Changes pathbar
    option.
  + Added search entry to toolbar.
  + Added function to attachment browser plugin to zoom icon size.
  + Added new template.
  + Critical bug fix for using templates that have a resources
    folder.
  + Fix for week number in Journal plugin page template (again).
  + Fix for focus switching with distraction free editing plugin.
  + Fix for handling BOM character at start of file.
  + Fixed quicknote dialog to ask for confirmation on discard.
  + Fix to allow calling executables that do not end in .exe on
    windows.
  + Fix for various typos in the manual.
  + Removed custom zim.www.Server class in favor of standard
    library version.
* Thu Jan 24 2013 zaitor@opensuse.org
- Update to version 0.59:
  + Fixed a critical bug in the editor widget that can lead to
    loss of content for specific combinations of formatting.
  + Fixed week numbers in Journal pages.
  + Improved Tasklist tag inheritance.
* Sun Dec 16 2012 dimstar@opensuse.org
- Update to version 0.58:
  + New plugin for distraction free fullscreen mode.
  + Added options to limit tasklist plugin to certain namespaces.
  + Added option to tasklist plugin to flag non-actionable tasks by
    a special tag.
  + Added prompt for filename for Insert New File action.
  + Added template option to list attachments in export.
  + Added class attributes to links in HTML output.
  + Added two more commandline options to quicknote plugin.
  + Made sidepanes more compact by embedding close buttons in
    widgets.
  + Critical fix for restarting zim after a crash (cleaning up
    socket).
  + Several bugs fixed.
  + Fix first day of week locale for calendar plugin.
  + Fix for handling "file:/" and "file://" URIs in links.
  + Fix for windows to not open consoles for each external
    application.
  + Fix for windows to put config files under %%APPDATA%%.
  + Fix to have "update heading" toggle in rename dialog more
    intelligent.
  + Fix to make template errors report relevant error dialogs.
  + Fix for search and replace whitespace in pageview.
  + Various small fixes.
* Fri Oct 12 2012 dimstar@opensuse.org
- Update to version 0.57:
  + New features:
  - Option to export to ReST
  + New plugins:
  - Insert music scores using GNU Lilypond
  - Zeitgeist integration.
  + A rework of the side panes
  + Allowing plugins to be positioned on any side
  + Simpler configuration for external applications
  + A critical bug fix for the version control plugin
  + Improved the attachment browser, the calendar plugin and the
    tasklist plugin.
  + Updated translations.
* Thu Apr 26 2012 vuntz@opensuse.org
- Cleanup package originally created by Matthias Propst
  <propstmatthias@googlemail.com> (using zim 0.55).
- Update to version 0.56:
  + Add support for version control with Mercurial and Git as
    backend in addition to the previous Bazaar support.
  + Add drag & drop support to attachment browser.
  + Notebooks now can have a notebook specific configuration
    "profile".
  + Add new plugin to handle "ditaa" diagrams.
  + Fix critical bug that prevented opening email addresses without
    a "mailto:" prefix.
  + Fix bug where context menu for page index applied to the
    current page.
  + Make sidepane and tagcloud remember state.
  + Updated translations.
